:mod:`kanon.tables.htable` --- Historical tables
================================================

.. currentmodule:: kanon.tables.htable

.. automodapi:: kanon.tables.htable
.. automodapi:: kanon.tables.hcolumn
